@@ -32,8 +32,6 @@ public:
 
     UsbDeviceMonitor* q_ptr;
 
-    // Handle to dynamically loaded udev library
-    void* m_udevLib;
     // udev library context
     struct udev* m_udev;
     // udev device monitor handle
